pub struct ParallelNode { /* private fields */ }Expand description
The ParallelNode execute all its children concurrently, but not in separate threads!
Even if this may look similar to ReactiveSequence, this Control Node is the only one that can have multiple children RUNNING at the same time.
The Node is completed either when the THRESHOLD_SUCCESS or THRESHOLD_FAILURE number is reached (both configured using ports).
If any of the thresholds is reached, and other children are still running, they will be halted.
Note that threshold indexes work as in Python: https://www.i2tutorials.com/what-are-negative-indexes-and-why-are-they-used/
Therefore -1 is equivalent to the number of children.
Implementations
Sourceimpl ParallelNode
impl ParallelNode
pub fn create_node(name: impl AsRef<str>, config: NodeConfig) -> TreeNode