pub struct ParallelAllNode { /* private fields */ }Expand description
The ParallelAllNode execute all its children concurrently, but not in separate threads!
It differs in the way ParallelNode works because the latter may stop and halt other children if a certain number of SUCCESS/FAILURES is reached, whilst this one will always complete the execution of ALL its children.
Note that threshold indexes work as in Python: https://www.i2tutorials.com/what-are-negative-indexes-and-why-are-they-used/
Therefore -1 is equivalent to the number of children.
Implementations
Sourceimpl ParallelAllNode
impl ParallelAllNode
pub fn create_node(name: impl AsRef<str>, config: NodeConfig) -> TreeNode