pub struct SequenceWithMemoryNode { /* private fields */ }Expand description
The SequenceStarNode is used to tick children in an ordered sequence. If any child returns RUNNING, previous children are not ticked again.
-
If all the children return SUCCESS, this node returns SUCCESS.
-
If a child returns RUNNING, this node returns RUNNING. Loop is NOT restarted, the same running child will be ticked again.
-
If a child returns FAILURE, stop the loop and return FAILURE. Loop is NOT restarted, the same running child will be ticked again.
Implementations
Sourceimpl SequenceWithMemoryNode
impl SequenceWithMemoryNode
pub fn create_node(name: impl AsRef<str>, config: NodeConfig) -> TreeNode